@@ -25,9 +25,9 @@ from nwmanager import NetworkManager
 import dbus.service
 import dbus.mainloop.qt
 
-__version__ = '0.0.13'
+__version__ = '0.0.14'
 AVATAR_CACHE_FOLDER = os.path.join(os.path.expanduser("~"),'.khweeteur','cache')
-CACHE_PATH = os.path.join(os.path.expanduser("~"), '.khweeteur','tweets.cache')
+CACHE_PATH = os.path.join(os.path.expanduser("~"), '.khweeteur')
 KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
 KHWEETEUR_TWITTER_CONSUMER_SECRET = 'lbKAvvBiyTlFsJfb755t3y1LVwB0RaoMoDwLD14VvU'
 KHWEETEUR_IDENTICA_CONSUMER_KEY = 'c7e86efd4cb951871200440ad1774413'
@@ -109,11 +109,12 @@ class KhweeteurWorker(QThread):
             if not(os.path.exists(cache)):
                 try:
                     urlretrieve(status.user.profile_image_url, cache)
+#                    QPixmap(cache).scaled(70,70,Qt.KeepAspectRatio).save(cache)
                 except StandardError,e:
                     print e
         
     def refresh_search(self):
-        print 'Try to refresh search :'+str(self.search_keyword)
+        print 'Try to refresh search : ',unicode(self.search_keyword).encode('UTF-8')
         downloadProfileImage = self.downloadProfileImage
                         
         current_dt = time.mktime((datetime.datetime.now() - datetime.timedelta(days=14)).timetuple())
@@ -122,40 +123,30 @@ class KhweeteurWorker(QThread):
             avatars_url={}
             if (self.settings.value("twitter_access_token_key").toString()!=''): 
                 api = twitter.Api(input_encoding='utf-8',username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key").toString()),access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-                for status in api.GetSearch(self.search_keyword):
+                for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8')):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
                         mlist.append((status.created_at_in_seconds,status))
-#                mlist.sort()
-#
-#                #DOwnload avatar & add tweet to the model
-#                for _,status in mlist:
-#                    self.downloadProfileImage(status)
-#                    #We are now in a thread
-#                    self.emit(SIGNAL("newStatus(PyQt_PyObject)"),status)
-
-            if (self.settings.value("twitter_access_token_key").toString()!=''): 
-                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
-                for status in api.GetSearch(self.search_keyword,per_page=50):
-                    if status.created_at_in_seconds > current_dt:
-                        downloadProfileImage(status)
-                        mlist.append((status.created_at_in_seconds,status))
-
-            if ((self.settings.value("twitter_access_token_key").toString()!='')) or ((self.settings.value("identica_access_token_key").toString()!='')): 
-
-                mlist.sort()
-
-                #DOwnload avatar & add tweet to the model
-#                for _,status in mlist:
-#                    self.downloadProfileImage(status)
-                    #We are now in a thread
-                self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
-
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
-        print 'Refresh search :'+str(self.search_keyword)
+        try:
+            if (self.settings.value("twitter_access_token_key").toString()!=''): 
+                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+                for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8'),per_page=50):
+                    if status.created_at_in_seconds > current_dt:
+                        downloadProfileImage(status)
+                        mlist.append((status.created_at_in_seconds,status))
+        except twitter.TwitterError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+
+            if ((self.settings.value("twitter_access_token_key").toString()!='')) or ((self.settings.value("identica_access_token_key").toString()!='')): 
+
+                mlist.sort()
+                self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
+
         
     def refresh(self):
         print 'Try to refresh'
@@ -169,12 +160,10 @@ class KhweeteurWorker(QThread):
                 for status in api.GetFriendsTimeline(count=100):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
-#                        status.qicon = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))))
                         mlist.append((status.created_at_in_seconds,status))
                 for status in api.GetReplies():
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
-#                        status.qicon = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))))
                         mlist.append((status.created_at_in_seconds,status))
                 for status in api.GetDirectMessages():
                     if status.created_at_in_seconds > current_dt:
@@ -182,9 +171,15 @@ class KhweeteurWorker(QThread):
                 for status in api.GetMentions():
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
-#                        status.qicon = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))))
                         mlist.append((status.created_at_in_seconds,status))                        
+        except twitter.TwitterError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except StandardError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
+        try:
             if (self.settings.value("identica_access_token_key").toString()!=''): 
                 api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
                 for status in api.GetFriendsTimeline(count=100):
@@ -205,6 +200,12 @@ class KhweeteurWorker(QThread):
                         downloadProfileImage(status)
 #                        status.qicon = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))))
                         mlist.append((status.created_at_in_seconds,status))                        
+        except twitter.TwitterError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
+        except StandardError,e:
+            print 'Error during refresh : ',e.message
+            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
             if ((self.settings.value("twitter_access_token_key").toString()!='')) or ((self.settings.value("identica_access_token_key").toString()!='')): 
 
@@ -216,13 +217,6 @@ class KhweeteurWorker(QThread):
                     #We are now in a thread
                 self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
 
-        except twitter.TwitterError,e:
-            print 'Error during refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except StandardError,e:
-            print 'Error during refresh : ',e.message
-            self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-
 #            KhweeteurNotification().info('Error occurs during refresh.')
 
 
@@ -359,23 +353,38 @@ class KhweetsModel(QAbstractListModel):
                         QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
                     else:
                         print 'Wrong cache format'
+                        KhweeteurNotification().info('Old cache format. Reinit cache.')            
         except:
             KhweeteurNotification().info('Wrong cache format. Reinit cache.')
             print 'Wrong cache format'
 
-    def serialize(self):
-        output = open(CACHE_PATH, 'wb')
-        pickle.dump(self._items, output)
-        output.close()
-
-    def unSerialize(self):
+    def serialize(self,keyword):
         try:
-            pkl_file = open(CACHE_PATH, 'rb')
+            if keyword==None:
+                filename = os.path.join(CACHE_PATH,'tweets.cache')
+            else:
+                filename = os.path.normcase(unicode(os.path.join(unicode(CACHE_PATH),unicode(keyword.replace('/','_'))+u'.cache'))).encode('UTF-8')               
+            output = open(filename, 'wb')
+            pickle.dump(self._items, output)
+            output.close()
+        except StandardError,e:
+            KhweeteurNotification().info('An error occurs while saving cache : '+str(e))
+            
+    def unSerialize(self,keyword):
+        try:
+            if keyword==None:
+                filename = os.path.join(CACHE_PATH,'tweets.cache')
+            else:
+                filename = os.path.normcase(unicode(os.path.join(unicode(CACHE_PATH),unicode(keyword.replace('/','_'))+u'.cache'))).encode('UTF-8')          
+            pkl_file = open(filename, 'rb')
             items = pickle.load(pkl_file)
             self.setData(items)
             pkl_file.close()
         except StandardError,e:
-            print e            
+            print 'unSerialize : ',e
+            # import traceback
+            # print traceback.print_exc()
+            # print traceback.print_stack()
         finally:
             #14 Day limitations
             current_dt = time.mktime((datetime.datetime.now() - datetime.timedelta(days=14)).timetuple())
@@ -441,7 +450,7 @@ class KhweeteurAbout(QMainWindow):
         aboutIcon = QLabel()
         aboutIcon.setPixmap(QPixmap(os.path.join(khweeteur.__path__[0],'icons','khweeteur.png')).scaledToHeight(128))
         aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
-        aboutIcon.resize(140,140)
+        aboutIcon.resize(128,128)
         aboutLayout.addWidget(aboutIcon)
 
         aboutLabel = QLabel('''<center><b>Khweeteur</b> %s
@@ -687,7 +696,7 @@ class KhweeteurWin(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
         if self.search_keyword != None:
-            self.setWindowTitle("Khweeteur:"+str(self.search_keyword))      
+            self.setWindowTitle("Khweeteur:"+unicode(self.search_keyword))      
         else:           
             self.setWindowTitle("Khweeteur")
 
@@ -724,8 +733,8 @@ class KhweeteurWin(QMainWindow):
         self.tweetsModel = KhweetsModel([])
         self.tweetsView.setModel(self.tweetsModel)
         self.setCentralWidget(self.tweetsView)
-        if self.search_keyword == None:
-            self.tweetsModel.unSerialize()
+#        if self.search_keyword == None:
+        self.tweetsModel.unSerialize(self.search_keyword)
 
         self.toolbar = self.addToolBar('Toolbar')
 
@@ -733,9 +742,9 @@ class KhweeteurWin(QMainWindow):
         self.connect(self.tb_open, SIGNAL('triggered()'), self.open_url)
         self.toolbar.addAction(self.tb_open)
         
-        self.tb_retweet = QAction(QIcon.fromTheme("general_refresh"),'Retweet', self)
-        self.connect(self.tb_retweet, SIGNAL('triggered()'), self.retweet)
-        self.toolbar.addAction(self.tb_retweet)
+        # self.tb_retweet = QAction(QIcon.fromTheme("general_refresh"),'Retweet', self)
+        # self.connect(self.tb_retweet, SIGNAL('triggered()'), self.retweet)
+        # self.toolbar.addAction(self.tb_retweet)
         
         self.tb_text = QLineEdit()
         self.tb_text_replyid = 0
@@ -763,7 +772,7 @@ class KhweeteurWin(QMainWindow):
 
 
     def countChar(self,text):
-        self.tb_charCounter.setText(str(140-text.count()))
+        self.tb_charCounter.setText(unicode(140-text.count()))
 
     def reply(self,index):
         user = self.tweetsModel._items[index.row()][2]
@@ -853,8 +862,8 @@ class KhweeteurWin(QMainWindow):
                 print e 
 
     def refreshEnded(self):
-        if self.search_keyword == None:
-            self.tweetsModel.serialize()
+#        if self.search_keyword == None:
+        self.tweetsModel.serialize(self.search_keyword)
         counter=self.tweetsModel.getNewAndReset()
         if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
             self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
@@ -910,6 +919,9 @@ class KhweeteurWin(QMainWindow):
                 QKeySequence(self.tr("Ctrl+R", "Update")))
         fileMenu.addAction(self.tr("&Search"), self.open_search,
                 QKeySequence(self.tr("Ctrl+S", "Search")))
+        fileMenu.addAction(self.tr("&Retweet"), self.retweet,
+                QKeySequence(self.tr("Ctrl+T", "Retweet")))
+                
         if self.search_keyword != None:
             keywords = self.settings.value('savedSearch').toPyObject()
             if keywords != None:
@@ -926,8 +938,12 @@ class KhweeteurWin(QMainWindow):
         keywords = self.settings.value('savedSearch').toPyObject()
         if keywords == None:
             keywords = []
-        keywords.remove(self.search_keyword)
+        else:
+            index = keywords.indexOf(self.search_keyword)
+            if index>=0:
+                keywords.removeAt(index)
         self.settings.setValue('savedSearch',QVariant(keywords))
+        self.close()
                                 
     def save_search(self):
         keywords = self.settings.value('savedSearch').toPyObject()
