@@ -18,7 +18,7 @@
 '''A library that provides a Python interface to the Twitter API'''
 
 __author__ = 'python-twitter@googlegroups.com'
-__version__ = '0.8-khtfork'
+__version__ = '0.8-khtfork.2'
 
 
 import base64
@@ -1556,7 +1556,7 @@ class Api(object):
 
     # Make and send requests
     url  = 'http://search.twitter.com/search.json'
-    json = self._FetchUrl(url, parameters=parameters)
+    json = self._FetchUrl(url, post_data=parameters)
     data = simplejson.loads(json)
 
     self._CheckForTwitterError(data)
@@ -1817,11 +1817,14 @@ class Api(object):
     Returns:
       A of list twitter.Status instance representing the messages posted.
     '''
-    results = list()
-    line_length = CHARACTER_LIMIT - 4
-    lines = textwrap.wrap(status, line_length)
+    results = list()    
+    line_length = CHARACTER_LIMIT
+    lines = textwrap.wrap(status, line_length)    
     if len(lines) > 9:
         line_length = CHARACTER_LIMIT - 6
+        lines = textwrap.wrap(status, line_length)                
+    elif len(lines) > 1:
+        line_length = CHARACTER_LIMIT - 4
         lines = textwrap.wrap(status, line_length)        
     counter = 1
     if len(lines)==1:
